# LPV
## Fast Python Parser Library

### About:
LPV/LexParserVisit is a Python parser library for parsing or lexing. LPV also has AST for executing node tree.

### Usage:
examples are [here](https://github.com/Xp-op/LPV/tree/main/example)

### Contributing:
Any contributions is greatly appreciated.

### Documentation:
The documentation is still in progress. You can learn it by 
[example](https://github.com/Xp-op/LPV/tree/main/example) for now.